name = "krateng"
desc = "Metapackage for my system setup"
author = {
	"name":"Johannes Krattenmacher",
	"email":"misc@dev.krateng.ch",
	"github": "krateng"
}
version = 1,0,0
versionstr = ".".join(str(n) for n in version)
links = {
	"pypi":"krateng",
	"github":"kratengpy"
}
python_version = ">=3.6"
requires = [
	"borgbackup",
	"doreah",
	"jinja2",
	"lxml",
	"MechanicalSoup",
	"PyYAML",
	"requests",
	"s3cmd",
	"selenium"
	"Send2Trash",
	"tabulate",
	"waitress",
	"yeonji",
	"youtube-dl",
	
]
resources = [
]

commands = {
}
